ValidationOptions class final

Options that control how schemas are compared to find mismatches.

Constructors

ValidationOptions({bool validateDropped = false, bool validateColumnConstraints = true})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateColumnConstraints → bool
When enabled (defualts to true), validate column constraints.
final
validateDropped → bool
When enabled (defaults to false), validate that no furhter tables, triggers or views apart from those expected exist.
final

Methods

applyDeprecatedValidateDroppedParam(bool? validateDropped) → ValidationOptions
Returns new ValidationOptions with the ValidationOptions.validateDropped field replaced if validateDropped is not null.validateDropped
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited