VerifySelf extension

Utilities verifying that the current schema of the database matches what the generated code expects.

on
  • GeneratedDatabase

Methods

validateDatabaseSchema({required DriftConnection connection, ValidationOptions options = const common.ValidationOptions()}) Future<void>

Available on GeneratedDatabase, provided by the VerifySelf extension

Compares and validates the schema of the current database with what the generated code expects.