declaredTables property
All tables that have been declared on this accessor directly.
This contains the tables field from a UseMoor or UseDao annotation,
but not tables that are declared in imported moor files. Use tables for
that.
Implementation
final List<MoorTable> declaredTables;